@@ -96,8 +96,16 @@ def getscores(rankby):
         
         ProteinA=resultname.split("-")[0]
         ProteinB=resultname.split("-")[1]
-        ProteinAmin=ProteinA.split("_")[0]+"_"+ProteinA.split("_")[1]
-        ProteinBmin=ProteinB.split("_")[0]+"_"+ProteinB.split("_")[1]
+
+        if len(ProteinA.split("_")) == 4: #Those from uniprot have "NAME_HUMAN_1_100" or similar
+            ProteinAmin=ProteinA.split("_")[0]+"_"+ProteinA.split("_")[1]
+        else: #not from uniprot
+            ProteinAmin=ProteinA.split("_")[0]
+        if len(ProteinB.split("_")) == 4: #Those from uniprot have "NAME_HUMAN_1_100" or similar
+            ProteinBmin=ProteinB.split("_")[0]+"_"+ProteinB.split("_")[1]
+        else: #not from uniprot
+            ProteinBmin=ProteinB.split("_")[0]
+
         proteinA_lst.append(ProteinA)
         proteinB_lst.append(ProteinB)
          
@@ -106,7 +114,7 @@ def getscores(rankby):
         if scorewildcard == "_scores.json":
             for path in Path(resultdir).glob("*_model_*_scores.json"):
                 paejsons.append(str(path))
-                paenumlst.append(int(str(path).split("_scores.json")[0].split("_model_")[-1])-1)
+                paenumlst.append(int(str(path).split("_scores.json")[0].split("_model_")[-1].split("_seed")[0])-1)
         elif scorewildcard == "_pae.json":
             for path in Path(resultdir).glob("rank_*_model_*_ptm_seed_0_pae.json"):
                 paejsons.append(str(path))
@@ -130,19 +138,37 @@ def getscores(rankby):
                 print("Could not find uniprot ID for " + ProteinBmin)
 
 
+        foundflag=False
         if rankby in ["iptm", "ptm"]:
             if rankby == "iptm":
                 m = np.argmax(iptms)
             else:
                 m = np.argmax(ptms)
+
         elif rankby=="scaledPAE":
             minpaes=[]
-            for paejson in paejsons:
-                minpaes.append(getmincrosspae(paejson))
-            m = paenumlst[np.argmin(minpaes)]
+            rankfile = resultdir+"/bestpaerank.txt"
+            if os.path.exists(rankfile) and os.stat(rankfile).st_size != 0:
+                with open(rankfile) as f:
+                    lines = [line for line in f.readlines()]
+                if ":" in lines[-1]:
+                    m = int(lines[-1].split(":")[-1])-1
+                    minpaes = [line.strip() for line in lines[:-1]]
+                    minpaes = [float(i.split("=")[-1]) for i in minpaes]                   
+                    foundflag=True
+
+            if not foundflag:
+                with open(rankfile, 'w') as f:
+                    for paenum, paejson in zip(paenumlst, paejsons):
+                        minpae = getmincrosspae(paejson)
+                        minpaes.append(minpae)
+                        f.write("model"+str(paenum+1)+"="+str(minpae)+"\n")
+                    m = paenumlst[np.argmin(minpaes)]
+                    f.write("bestmodel:"+str(m+1))
             # For the future: if same crosspae, choose best iptm
             # if len([k for k in minpaes if k == min(minpaes)]) > 1:
             #     print("there are multiple solutions for " + str(scorepath))
+        
         else:
             sys.exit("\n>> Provide ptm, iptm, or pae as the ranking method.\n")
 
@@ -194,7 +220,10 @@ def make_paeplot(pae, protnames, protlens):
     yticklocs = []
     newprotnames = []
     for i, p in enumerate(protnames):
-        newprotnames.append(p.split("_")[0]+"\n"+p.split("_")[2]+"-"+p.split("_")[3])
+        if len(p.split("_")) == 4: #Those from uniprot have "NAME_HUMAN_1_100" or similar
+            newprotnames.append(p.split("_")[0]+"\n"+p.split("_")[2]+"-"+p.split("_")[3])
+        else:
+            newprotnames.append(p.split("_")[0]+"\n"+p.split("_")[1]+"-"+p.split("_")[2])
         
     for n, l in zip(protnames, protlens):
         
